@@ -1,9 +1,9 @@
 package urpm::main_loop;
 
-# $Id: main_loop.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 #- Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 #- Copyright (C) 2005-2010 Mandriva SA
+#- Copyright (C) 2011-2020 Mageia
 #-
 #- This program is free software; you can redistribute it and/or modify
 #- it under the terms of the GNU General Public License as published by
@@ -223,13 +223,14 @@ sub _init_common_options {
       callback_open_helper => $callbacks->{open_helper},
       callback_trans => $callbacks->{trans},
       callback_uninst => $callbacks->{uninst},
+      callback_verify => $callbacks->{verify},
       raw_message => 1,
   );
 }
 
 sub _log_installing {
     my ($urpm, $transaction_sources_install, $transaction_sources) = @_;
-    if (my @packnames = (values $transaction_sources_install, values $transaction_sources)) {
+    if (my @packnames = (values %$transaction_sources_install, values %$transaction_sources)) {
         (my $common_prefix) = $packnames[0] =~ m!^(.*)/!;
         if (length($common_prefix) && @packnames == grep { m!^\Q$common_prefix/! } @packnames) {
             #- there's a common prefix, simplify message
@@ -242,7 +243,7 @@ sub _log_installing {
 
 sub _run_parallel_transaction {
     my ($urpm, $state, $transaction_sources, $transaction_sources_install) = @_;
-    $urpm->{print}(N("distributing %s", join(' ', values $transaction_sources_install, values $transaction_sources)));
+    $urpm->{print}(N("distributing %s", join(' ', values %$transaction_sources_install, values %$transaction_sources)));
     #- no remove are handle here, automatically done by each distant node.
     $urpm->{log}("starting distributed install");
     $urpm->{parallel_handler}->parallel_install(
@@ -634,6 +635,6 @@ Copyright (C) 1999-2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2013 Mageia
+Copyright (C) 2011-2020 Mageia
 
 =cut
